@@ -70,6 +70,11 @@ def svd(a: Numeric, compute_uv: bool = True):
     return (res[0], res[1], anp.conj(transpose(res[2]))) if compute_uv else res
 
 
+@dispatch
+def eig(a: Numeric, compute_eigvecs: bool = True):  # pragma: no cover
+    raise NotImplementedError("Function `quantile` is not available for AutoGrad.")
+
+
 @dispatch
 def solve(a: Numeric, b: Numeric):
     return anp.linalg.solve(a, b)
