@@ -52,6 +52,12 @@ def svd(a: Numeric, compute_uv: bool = True):
     return (res[0], res[1], np.conj(transpose(res[2]))) if compute_uv else res
 
 
+@dispatch
+def eig(a: Numeric, compute_eigvecs: bool = True):
+    vals, vecs = np.linalg.eig(a)
+    return (vals, vecs) if compute_eigvecs else vals
+
+
 @dispatch
 def solve(a: Numeric, b: Numeric):
     return np.linalg.solve(a, b)
