@@ -62,6 +62,12 @@ def svd(a: Numeric, compute_uv: bool = True):
     return (res[1], res[0], res[2]) if compute_uv else res
 
 
+@dispatch
+def eig(a: Numeric, compute_eigvecs: bool = True):
+    vals, vecs = tf.linalg.eig(a)
+    return (vals, vecs) if compute_eigvecs else vals
+
+
 @dispatch
 def solve(a: Numeric, b: Numeric):
     return tf.linalg.solve(a, b)
