@@ -22,10 +22,10 @@ def resolve_axis(a, axis):
     Return:
         int: Resolved axis.
     """
-    while axis < 0:
+    if axis < 0:
         axis = B.rank(a) + axis
     if not (0 <= axis < B.rank(a)):
-        raise RuntimeError(
+        raise ValueError(
             f"Axis {axis} cannot be resolved for tensor of shape {B.shape(a)}."
         )
     return axis
